@@ -1,6 +1,6 @@
 <?php
 // t@C쐬
-$filename = $MOWIKI_DATA.rawurlencode($gIn['title']).'.txt';
+$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
 
 // t@C̑݃`FbN
 if (file_exists($filename)) {
