@@ -1,10 +1,9 @@
 <?php
 // t@CXVEۑ
-$filename = $MOWIKI_DATA.rawurlencode($gIn['title']).'.txt';
+$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
 
 // XV`FbN
 if (file_exists($filename)) {
-  // if (filemtime($filename) > $gIn['ts']) {
   if (filemtime($filename) > $gIn['ts']) {
 	// G[
 	print "ERROR<br>XV`FbNɂЂ܂<br>uEU̖߂Ŗ߂ĉ";
@@ -17,9 +16,14 @@ if (file_exists($filename)) { // t@C݂ꍇ
   unlink($filename);
 }
 
+// ϊ
+$gOut['body'] = $gIn['body'];
+$gOut['body'] = preg_replace("/$MOWIKI_DATE/", date($MOWIKI_DATE_FORMAT), $gOut['body']);
+$gOut['body'] = preg_replace("/$MOWIKI_TIME/", date($MOWIKI_TIME_FORMAT), $gOut['body']);
+
 // t@Cɏ
 $fp = fopen($filename, 'a+');
-fputs($fp, $gIn['body']);
+fputs($fp, $gOut['body']);
 fclose($fp);
 
 ?>
\ No newline at end of file
