@@ -12,7 +12,7 @@
 <?php print $gOut['body']?>
 <hr color="<?php print $MOWIKI_HR?>">
 <?php if ($gOut['edit'] == 1) { ?>
-<a href="<?php print $_SERVER['PHP_SELF']?>?a=M&title=<?php print rawurlencode($gIn['title'])?>" accesskey="0">̃y[WҏW</a><br>
+<a href="<?php print $_SERVER['PHP_SELF']?>?a=M&title=<?php print encode($gIn['title'])?>" accesskey="0">̃y[WҏW</a><br>
 <?php } ?>
 <br>
 Admin: <?php print $MOWIKI_ADMIN?><br>
